@@ -10,10 +10,13 @@ summary_patristic_matrix_array <- function(patristic_matrix_array, fn = stats::m
 
 
 
-#' Find the index of relevant studies in a opentree_chronograms object. Used inside: summarize_datelife_result.
+#' Find the index of relevant studies in a cached chronogram database.
+#'
+#' `datelife_result_study_index` is used in [summarize_datelife_result()].
+#'
 #' @inheritParams summarize_datelife_result
-#' @param cache The cache of studies
-#' @return A vector with the indices of studies that have relevant info
+#' @inheritParams datelife_authors_tabulate
+#' @return A vector of indices of studies that have relevant information.
 datelife_result_study_index <- function(datelife_result,
                                         cache = "opentree_chronograms") {
   if ("opentree_chronograms" %in% cache) {
@@ -23,26 +26,36 @@ datelife_result_study_index <- function(datelife_result,
   return(which(names(cache$trees) %in% names(datelife_result)))
 }
 
-#' Figure out which subset function to use. Used inside [get_datelife_result()]
-#' @param study_element The thing being passed in: an array or a phylo object to serve as reference for congruification
-#' @param taxa Vector of taxon names to get a subset for
-#' @param phy A user tree to congruify as phylo object (ape)
-#' @param phy4 A user tree to congruify in phylo4 format (phylobase)
+#' Figure out which subset function to use.
+#'
+#' `get_subset_array_dispatch` is used inside [get_datelife_result()]
+#'
+#' @param study_element The thing being passed in: an `array` or a `phylo` object
+#'  to serve as reference for congruification.
+#' @param taxa Vector of taxon names to get a subset for.
+#' @param phy A user tree to congruify as `phylo` object (ape).
+#' @param phy4 A user tree to congruify in `phylo4` format (phylobase).
 #' @param dating_method The method used for tree dating.
 #' @return A patristic matrix with ages for the target taxa.
-get_subset_array_dispatch <- function(study_element, taxa, phy = NULL, phy4 = NULL, dating_method = "PATHd8") {
+get_subset_array_dispatch <- function(study_element,
+                                      taxa, phy = NULL,
+                                      phy4 = NULL,
+                                      dating_method = "PATHd8") {
   if (class(study_element) == "array") {
     return(patristic_matrix_array_subset_both(study_element, taxa, phy, phy4, dating_method))
   } else {
-    return(phylo_subset_both(reference_tree.in = study_element, taxa.in = taxa, phy.in = phy, phy4.in = phy4, dating_method.in = dating_method))
+    return(phylo_subset_both(reference_tree = study_element, taxa = taxa, phy = phy, phy4 = phy4, dating_method = dating_method))
   }
 }
 
-#' Take results_list and process it. Used inside: get_datelife_result
-#' @param results_list A list returned from using get_subset_array_dispatch on opentree_chronograms$trees
-#' @param taxa A vector of taxa to match
-#' @param partial If TRUE, return matrices that have only partial matches
-#' @return A list with the patristic.matrices that are not NA
+#' Take results_list and process it.
+#'
+#' `results_list_process` is used inside: [get_datelife_result()]
+#'
+#' @param results_list A `list` returned from using [get_subset_array_dispatch()] on `opentree_chronograms$trees`
+#' @inheritParams get_subset_array_dispatch
+#' @param partial If `TRUE`, return matrices that have only partial matches.
+#' @return A list with the patristic.matrices that are not `NA`.
 results_list_process <- function(results_list, taxa = NULL, partial = FALSE) {
   if (is.null(taxa)) {
     taxa <- unique(unname(unlist(lapply(final_matrices, rownames))))
@@ -68,15 +81,25 @@ results_list_process <- function(results_list, taxa = NULL, partial = FALSE) {
   return(final_matrices)
 }
 
-#' Are all desired taxa in the patristic_matrix? Used inside: results_list_process.
-#' @param patristic_matrix A patristic matrix, rownames and colnames must be taxa
-#' @param taxa A vector of taxon names
-#' @return A Boolean
+#' Are all desired taxa in the patristic matrix?
+#'
+#' `patristic_matrix_taxa_all_matching` is used inside: [results_list_process()].
+#'
+#' @param patristic_matrix A patristic matrix, `rownames` and `colnames` must be taxa.
+#' @inheritParams get_subset_array_dispatch
+#' @return A Boolean.
 patristic_matrix_taxa_all_matching <- function(patristic_matrix, taxa) {
   return(sum(!(taxa %in% rownames(patristic_matrix))) == 0)
 }
 
-# Used inside: get_subset_array_dispatch.
+
+#' Are all desired taxa in the patristic matrix array?
+#'
+#' `patristic_matrix_array_subset_both` is used inside [get_subset_array_dispatch()].
+#'
+#' @param patristic_matrix_array A patristic matrix array, `rownames` and `colnames` must be taxa.
+#' @inheritParams get_subset_array_dispatch
+#' @inherit get_subset_array_dispatch return
 patristic_matrix_array_subset_both <- function(patristic_matrix_array, taxa, phy = NULL, phy4 = NULL, dating_method = "PATHd8") {
   if (is.null(phy)) {
     return(patristic_matrix_array_subset(patristic_matrix_array = patristic_matrix_array, taxa = taxa, phy4 = phy4))
@@ -85,7 +108,9 @@ patristic_matrix_array_subset_both <- function(patristic_matrix_array, taxa, phy
   }
 }
 
-# Used inside: patristic_matrix_array_subset_both
+#' Subset a patristic matrix array
+#' @inheritParams patristic_matrix_array_subset_both
+#' @return A list with a patristic matrix array and a `$problem` if any.
 patristic_matrix_array_subset <- function(patristic_matrix_array, taxa, phy4 = NULL) {
   # gets a subset of the patristic_matrix_array. If you give it a phylo4 object, it can check to see if taxa are a clade
   patristic_matrix_array <- patristic_matrix_array[rownames(patristic_matrix_array) %in% taxa, colnames(patristic_matrix_array) %in% taxa, ]
@@ -106,8 +131,14 @@ patristic_matrix_array_subset <- function(patristic_matrix_array, taxa, phy4 = N
   return(list(patristic_matrix_array = patristic_matrix_array, problem = problem))
 }
 
-# Used inside: patristic_matrix_array_subset_both. patristic_matrix_array_congruify
-patristic_matrix_array_congruify <- function(patristic_matrix_array, taxa, phy = NULL,
+
+#' `patristic_matrix_array_congruify` is used for patristic_matrix_array_subset_both and patristic_matrix_array_congruify.
+#'
+#' @inheritParams patristic_matrix_array_subset_both
+#' @inherit patristic_matrix_array_subset_both return
+patristic_matrix_array_congruify <- function(patristic_matrix_array,
+                                             taxa,
+                                             phy = NULL,
                                              dating_method = "PATHd8") {
   # gets a subset of the patristic_matrix_array.
   patristic_matrix_array <- patristic_matrix_array[rownames(patristic_matrix_array) %in% taxa, colnames(patristic_matrix_array) %in% taxa, ]
@@ -126,17 +157,21 @@ patristic_matrix_array_congruify <- function(patristic_matrix_array, taxa, phy =
   return(list(patristic_matrix_array = patristic_matrix_array, problem = problem))
 }
 
-# Used inside: patristic_matrix_array_congruify
+#' Split a patristic matrix array
+#' Used inside: patristic_matrix_array_congruify
+#' @inheritParams patristic_matrix_array_congruify
+#' @return  A patristic matrix 3d array.
 patristic_matrix_array_split <- function(patristic_matrix_array) {
+  asub_for_lapply <- function(idx, x, dims = 3) {
+    return(abind::asub(x, idx, dims))
+  }
   return(lapply(sequence(dim(patristic_matrix_array)[3]), asub_for_lapply, patristic_matrix_array))
 }
 
-# Used inside: patristic_matrix_array_split to asub.list?
-asub_for_lapply <- function(idx, x, dims = 3) {
-  return(abind::asub(x, idx, dims))
-}
-
-#' Convert list of patristic matrices to a 3D array. Used inside: summarize_datelife_result, patristic_matrix_array_congruify.
+#' Convert list of patristic matrices to a 3D array.
+#'
+#' `patristic_matrix_list_to_array` us ised inside [summarize_datelife_result()], [patristic_matrix_array_congruify()].
+#'
 #' @param patristic_matrix_list List of patristic matrices
 #' @param pad If TRUE, pad missing entries
 #' @return A 3d array of patristic matrices
@@ -159,10 +194,15 @@ patristic_matrix_list_to_array <- function(patristic_matrix_list, pad = TRUE) {
   return(abind::abind(patristic_matrix_list, along = 3))
 }
 
-#' Function to fill in empty cells in a patristic matrix for missing taxa. Used in: patristic_matrix_list_to_array.
-#' @param patristic_matrix A patristic matrix with row and column names for taxa
-#' @param all_taxa A vector of the names of all taxa you want, including ones not in the patristic matrix
-#' @return patristic_matrix for all_taxa, with NA for entries between taxa where at least one was not in the original patristic_matrix
+#' Fill in empty cells in a patristic matrix for missing taxa.
+#'
+#' Used in: [patristic_matrix_list_to_array()].
+#'
+#' @inheritParams patristic_matrix_taxa_all_matching
+#' @param all_taxa A vector of names of all taxa you want, including ones not
+#' in the patristic matrix.
+#' @return A patristic matrix, with `NA` for entries between taxa
+#' where at least one was not in the original patristic matrix.
 patristic_matrix_pad <- function(patristic_matrix, all_taxa) {
   number.missing <- length(all_taxa) - dim(patristic_matrix)[1]
   final_matrix <- patristic_matrix
@@ -175,15 +215,27 @@ patristic_matrix_pad <- function(patristic_matrix, all_taxa) {
   return(patristic_matrix_name_reorder(final_matrix))
 }
 
-#' Function to reorder a matrix so that row and column labels are in alphabetical order. Used in: patristic_matrix_pad.
-#' @param patristic_matrix A patristic matrix with row and column names for taxa
-#' @return patristic_matrix A patristic matrix with row and column names for taxa in alphabetical order
+#' Reorder a matrix so that row and column labels are in alphabetical order.
+#'
+#' `patristic_matrix_name_reorder` is only used in: [patristic_matrix_pad()].
+#'
+#' @inheritParams patristic_matrix_taxa_all_matching
+#' @return A patristic matrix with row and column names for taxa in alphabetical order.
 patristic_matrix_name_reorder <- function(patristic_matrix) {
   return(patristic_matrix[order(rownames(patristic_matrix)), order(colnames(patristic_matrix))])
 }
 
-# Used in: patristic_matrix_list_to_array.
-patristic_matrix_name_order_test <- function(patristic_matrix, standard.rownames,
+
+#' Test the name order of a patristic matrix so that row and column labels are in alphabetical order.
+#'
+#' `patristic_matrix_name_order_test` is only used in [patristic_matrix_list_to_array()].
+#'
+#' @inheritParams patristic_matrix_taxa_all_matching
+#' @param standard.rownames A character vector of row names.
+#' @param standard.colnames A character vector of column names.
+#' @return Boolean.
+patristic_matrix_name_order_test <- function(patristic_matrix,
+                                             standard.rownames,
                                              standard.colnames) {
   if (compare::compare(rownames(patristic_matrix), standard.rownames)$result != TRUE) {
     return(FALSE)
@@ -195,15 +247,23 @@ patristic_matrix_name_order_test <- function(patristic_matrix, standard.rownames
 }
 
 # Used inside: patristic_matrix_array_congruify.
-patristic_matrix_array_phylo_congruify <- function(patristic_matrix, target_tree,
-                                                   dating_method = "PATHd8", attempt.fix = TRUE) {
+#' Congruify a patristic matrix array from a given `phylo` object.
+#' @inheritParams patristic_matrix_taxa_all_matching
+# # ' @inheritParams patristic_matrix_array_congruify
+# # ' @inheritParams phylo_get_subset_array
+#' @inheritParams phylo_congruify
+#' @inherit phylo_congruify return
+patristic_matrix_array_phylo_congruify <- function(patristic_matrix,
+                                                   target_tree,
+                                                   dating_method = "PATHd8",
+                                                   attempt_fix = TRUE) {
   result_matrix <- matrix(nrow = dim(patristic_matrix)[1], ncol = dim(patristic_matrix)[2])
   if (is.null(target_tree$edge.length)) {
     target_tree$edge.length <- numeric(nrow(target_tree$edge))
   }
   try(result_matrix <- phylo_to_patristic_matrix(congruify_and_check(
     reference = patristic_matrix_to_phylo(patristic_matrix),
-    target = target_tree, scale = dating_method, attempt.fix = attempt.fix
+    target = target_tree, scale = dating_method, attempt_fix = attempt_fix
   )))
   return(result_matrix)
 }
@@ -223,13 +283,18 @@ patristic_matrix_array_phylo_congruify <- function(patristic_matrix, target_tree
 
 # in case we want to cache. Not clear we do.
 # Used inside: patristic_matrix_array_phylo_congruify, phylo_get_subset_array and phylo_congruify
+#' Get a patristic matrix from a `phylo` object.
+#' @inheritParams phylo_check
+#' @inheritParams congruify_and_check
+#' @param test Default to `TRUE`. Whether to test if `phy` has branch lengths and is ultrametric or not.
+#' @return A patristic matrix.
 phylo_to_patristic_matrix <- function(phy, test = TRUE, tol = 0.01, option = 2) {
   # stores the distance between taxa
   patristic_matrix <- NA
   if (class(phy) == "phylo") {
     if (test) {
       if (!ape::is.ultrametric(phy, tol = tol, option = option)) {
-        stop("currently we require that chronograms be ultrametric") # can pad them so that terminals all reach to present
+        stop("Currently, datelife require that chronograms are ultrametric.") # can pad them so that terminals all reach to present
       }
     }
     patristic_matrix <- stats::cophenetic(phy)
@@ -238,30 +303,52 @@ phylo_to_patristic_matrix <- function(phy, test = TRUE, tol = 0.01, option = 2)
 }
 
 # Used inside: get_subset_array_dispatch.
-phylo_subset_both <- function(reference_tree.in, taxa.in, phy.in = NULL, phy4.in = NULL, dating_method.in = "PATHd8") {
+#' Subset a reference and a target tree given as `phylo` objects.
+#' @inheritParams get_subset_array_dispatch
+#' @inheritParams phylo_get_subset_array
+#' @inherit phylo_get_subset_array return
+phylo_subset_both <- function(reference_tree,
+                              taxa,
+                              phy = NULL,
+                              phy4 = NULL,
+                              dating_method = "PATHd8") {
   # COMMENTING OUT: OpenTree gives single trees, let's just standardize on those
   #  if (inherits(reference_tree, "phylo")) {
   #    reference_tree<-c(reference_tree) #from here in, assumes multiphylo object, even if a single tree
   #  }
   congruify <- FALSE
-  if (inherits(phy.in, "phylo")) {
+  if (inherits(phy, "phylo")) {
     congruify <- TRUE
   } else {
     congruify <- FALSE
   }
   if (congruify) {
-    return(phylo_get_subset_array_congruify(reference_tree = reference_tree.in, taxa = taxa.in, phy = phy.in, dating_method = dating_method.in))
+    return(phylo_get_subset_array_congruify(reference_tree = reference_tree,
+                                            taxa = taxa,
+                                            phy = phy,
+                                            dating_method = dating_method))
   } else { # when congruify is FALSE:
-    return(phylo_get_subset_array(reference_tree = reference_tree.in, taxa = taxa.in, phy4 = phy4.in, dating_method = dating_method.in))
+    return(phylo_get_subset_array(reference_tree = reference_tree,
+                                  taxa = taxa,
+                                  phy4 = phy4,
+                                  dating_method = dating_method))
   }
 }
 
 # Used inside: phylo_subset_both, when we don't congruify
-phylo_get_subset_array <- function(reference_tree, taxa, phy4 = NULL, dating_method = "PATHd8") {
+#' Get a subset array from a `phylo` object
+#' @param reference_tree A `phylo` object.
+#' @inheritParams get_subset_array_dispatch
+#' @inherit patristic_matrix_array_subset return
+phylo_get_subset_array <- function(reference_tree,
+                                   taxa,
+                                   phy4 = NULL,
+                                   dating_method = "PATHd8") {
   final.size <- sum(reference_tree$tip.label %in% taxa) # returns number of matches
   if (final.size >= 2) { # it's worth doing the pruning
     reference_tree <- phylo_prune_missing_taxa(reference_tree, taxa)
-    # reference_tree <- phylo_prune_missing_taxa(reference_tree, taxa) #phylo_prune_missing_taxa (PruneTree before) is the new, fast fn from Klaus Schliep. Eventually will be in phangorn, currently in datelife2
+    # phylo_prune_missing_taxa (PruneTree before) is the new, fast fn from Klaus Schliep.
+    # Eventually will be in phangorn, currently in datelife
   }
   problem <- "none"
   patristic_matrix_array <- NA
@@ -284,11 +371,19 @@ phylo_get_subset_array <- function(reference_tree, taxa, phy4 = NULL, dating_met
 }
 
 # Used inside: phylo_subset_both.
-phylo_get_subset_array_congruify <- function(reference_tree, taxa, phy = NULL, dating_method = "PATHd8") {
+#' Get a congruified subset array from a `phylo` object
+#' @inheritParams phylo_get_subset_array
+#' @inheritParams get_subset_array_dispatch
+#' @inherit patristic_matrix_array_subset return
+phylo_get_subset_array_congruify <- function(reference_tree,
+                                             taxa,
+                                             phy = NULL,
+                                             dating_method = "PATHd8") {
   final.size <- sum(reference_tree$tip.label %in% taxa) # returns number of matches
   if (final.size >= 2) { # it's worth doing the pruning
     reference_tree <- phylo_prune_missing_taxa(reference_tree, taxa)
-    # reference_tree <- phylo_prune_missing_taxa(reference_tree, taxa)  # phylo_prune_missing_taxa (used to be names PruneTree) is the new, fast fn from Klaus Schliep. Eventually will be in phangorn, currently in datelife2
+    # phylo_prune_missing_taxa (used to be names PruneTree) is the new, fast fn from Klaus Schliep.
+    # Eventually will be in phangorn, currently in datelife
   }
   problem.new <- "none"
   patristic_matrix_array.new <- NA
@@ -306,24 +401,40 @@ phylo_get_subset_array_congruify <- function(reference_tree, taxa, phy = NULL, d
   return(list(patristic_matrix_array = patristic_matrix_array.new, problem = problem.new))
 }
 
-# Used inside: phylo_get_subset_array and phylo_get_subset_array_congruify.
+#' Prune missing taxa from a `phylo` object
+#' Used inside phylo_get_subset_array and phylo_get_subset_array_congruify.
+#' @inheritParams get_subset_array_dispatch
+#' @return A `phylo` object.
 phylo_prune_missing_taxa <- function(phy, taxa) {
   return(ape::drop.tip(phy, tip = phy$tip.label[-(which(phy$tip.label %in% taxa))]))
 }
 
 # Used inside: phylo_get_subset_array_congruify.
-phylo_congruify <- function(reference_tree, target_tree, dating_method = "PATHd8", attempt.fix = TRUE) {
+#' Congruify a reference tree and a target tree given as `phylo` objects.
+#' @inheritParams summary_matrix_to_phylo
+#' @inheritParams phylo_get_subset_array
+#' @inheritParams congruify_and_check
+#' @return A matrix.
+phylo_congruify <- function(reference_tree,
+                            target_tree,
+                            dating_method = "PATHd8",
+                            attempt_fix = TRUE) {
   result_matrix <- matrix(nrow = ape::Ntip(reference_tree), ncol = ape::Ntip(reference_tree))
   if (is.null(target_tree$edge.length)) {
     target_tree$edge.length <- numeric(nrow(target_tree$edge)) # makes it so that branches that don't match reference tree get zero length
   }
-  try(result_matrix <- phylo_to_patristic_matrix(congruify_and_check(reference = reference_tree, target = target_tree, scale = dating_method, attempt.fix = attempt.fix)))
+  try(result_matrix <- phylo_to_patristic_matrix(congruify_and_check(reference = reference_tree, target = target_tree, scale = dating_method, attempt_fix = attempt_fix)))
   return(result_matrix)
 }
 
 # Used inside: patristic_matrix_array_phylo_congruify and phylo_congruify.
+#' Congruify and Check.
+#' @inheritParams geiger::congruify.phylo
+#' @inheritParams ape::is.ultrametric
+#' @param attempt_fix Default to `TRUE`. If congruification results in NA branch
+#' lengths, it will attempt to fix them.
 congruify_and_check <- function(reference, target, taxonomy = NULL, tol = 0.01,
-                                option = 2, scale = "pathd8", attempt.fix = TRUE) {
+                                option = 2, scale = "pathd8", attempt_fix = TRUE) {
   if (!ape::is.ultrametric(reference, tol = tol, option = option)) {
     return(NA)
   }
@@ -331,7 +442,7 @@ congruify_and_check <- function(reference, target, taxonomy = NULL, tol = 0.01,
     phylo_tiplabel_space_to_underscore(reference), phylo_tiplabel_space_to_underscore(target),
     taxonomy = taxonomy, tol = tol, scale = scale
   )$phy)) # suppressing warnings b/c geiger ignores tolerance
-  if (anyNA(new.tree$edge.length) & attempt.fix) {
+  if (anyNA(new.tree$edge.length) & attempt_fix) {
     message("Congruification resulted in NA edge lengths. Resolving polytomies and making up starting branch lengths")
     new.tree <- phylo_tiplabel_underscore_to_space(geiger::congruify.phylo(
       phylo_tiplabel_space_to_underscore(reference), phylo_tiplabel_space_to_underscore(
@@ -349,17 +460,25 @@ congruify_and_check <- function(reference, target, taxonomy = NULL, tol = 0.01,
 }
 
 
-#' Convert spaces to underscores in trees. Used in: make_mrbayes_runfile, get_mrbayes_node_calibrations, tree_get_singleton_outgroup, congruify_and_check, patristic_matrix_array_phylo_congruify.
+#' Convert spaces to underscores in trees.
+#'
+#' `phylo_tiplabel_space_to_underscore` is used in: [make_mrbayes_runfile()],
+#' [tree_get_singleton_outgroup()],
+#' [congruify_and_check()], [patristic_matrix_array_phylo_congruify()].
+#'
 #' @inheritParams phylo_check
-#' @return A phylo object
+#' @return A `phylo` object.
 phylo_tiplabel_space_to_underscore <- function(phy) {
   phy$tip.label <- gsub(" ", "_", phy$tip.label)
   return(phy)
 }
 
-#' Convert underscores to spaces in trees. Used inside: patristic_matrix_array_phylo_congruify, congruify_and_check.
+#' Convert underscores to spaces in trees.
+#'
+#' `phylo_tiplabel_underscore_to_space` is used inside [patristic_matrix_array_phylo_congruify()], [congruify_and_check()].
+#'
 #' @inheritParams phylo_check
-#' @return A phylo object
+#' @return A `phylo` object.
 phylo_tiplabel_underscore_to_space <- function(phy) {
   # a better name for this function would be underscore_to_blank
   # add method .phylo
